Class: ActiveAgent::Providers::RubyLLM::Messages::Assistant
- Inherits:
-
Base
- Object
- Common::BaseModel
- Base
- ActiveAgent::Providers::RubyLLM::Messages::Assistant
- Defined in:
- lib/active_agent/providers/ruby_llm/messages/assistant.rb
Overview
Assistant message for RubyLLM provider.
Drops extra fields that are part of the API response but not part of the message structure.
Method Summary
Methods inherited from Base
Methods inherited from Common::BaseModel
#<=>, #==, attribute, #deep_compact, #deep_dup, delegate_attributes, drop_attributes, inherited, #initialize, #inspect, keys, #merge!, required_attributes, #serialize, #to_h, #to_hash
Constructor Details
This class inherits a constructor from ActiveAgent::Providers::Common::BaseModel